@@ -28,7 +28,7 @@
 ## x = infsup (2, 3);
 ## y = infsup (1, 2);
 ## x == y
-##   @result{} 0
+##   @result{} ans =  0
 ## @end group
 ## @end example
 ## @seealso{@@infsup/subset, @@infsup/interior, @@infsup/disjoint}
