@@ -24,9 +24,9 @@
 ## @example
 ## @group
 ## floor (infsup (2.5, 3.5))
-##   @result{} [2, 3]
+##   @result{} ans = [2, 3]
 ## floor (infsup (-0.5, 5))
-##   @result{} [-1, +5]
+##   @result{} ans = [-1, +5]
 ## @end group
 ## @end example
 ## @seealso{@@infsup/ceil, @@infsup/round, @@infsup/roundb, @@infsup/fix}
