@@ -30,7 +30,7 @@
 ##   @result{} ans = 3
 ## @end group
 ## @end example
-## @seealso{@@infsup/mig, @@infsup/inf, @@infsup/sup}
+## @seealso{@@infsup/mig, @@infsup/smig, @@infsup/inf, @@infsup/sup}
 ## @end deftypefn
 
 ## Author: Oliver Heimlich
