@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} decorationpart (@var{X})
 ## 
 ## Return the decoration of the decorated interval @var{X}.
@@ -36,7 +36,15 @@ if (nargin ~= 1)
     return
 endif
 
-dec = x.dec;
+persistent dec_translation = {...
+    "ill", [], [], [], ...
+    "trv", [], [], [], ...
+    "def", [], [], [], ...
+    "dac", [], [], [], ...
+    "com"};
+
+dec = cell (size (x.dec));
+dec (:) = dec_translation (x.dec (:) + 1);
 
 endfunction
 
