@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} subsasgn (@var{A}, @var{IDX}, @var{RHS})
 ##
 ## Perform the subscripted assignment operation according to the subscript
@@ -54,16 +54,10 @@ if (isnai (B))
     return
 endif
 
-x = subsasgn (intervalpart (A), S, intervalpart (B));
-dx = subsasgn (A.dec, S, B.dec);
+result = newdec (subsasgn (intervalpart (A), S, intervalpart (B)));
+result.dec = subsasgn (A.dec, S, B.dec);
+result.dec (result.dec == 0) = _trv (); # any new elements are [Empty]_trv
 
-## Implicit new elements carry the value [Empty] and must be initialized with
-## decoration trv.  Old elements that have been [Empty] before, already have
-## the decoration trv.
-dx (isempty (x)) = "trv";
-
-result = infsupdec (x, dx);
- 
 endfunction
 
 %!test
